<?php

namespace BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin;

if (!defined('ABSPATH')) {
    exit('Sorry!');
} // Exit if accessed directly

require_once BSD_SCSP_PLUGIN_DIR . '/includes/vendor/autoload.php';
if (!class_exists('namespace BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin;
\BSD_SCA')) {
    class BSD_SCA
    {
        public function run()
        {
            add_action("admin_init", array($this, "bsd_connect_standard_account"));
            add_action("init", array($this, "bsd_connect_standard_account_cb"));

            add_action("admin_init", array($this, "get_initial_accounts"));
            add_action("wp_ajax_fetch_accounts", array($this, "fetch_accounts"));
            add_action("wp_ajax_clear_accounts", array($this, "clear_accounts"));
            add_action("wp_ajax_add_custom_account", array($this, "add_custom_account"));
            /* if (function_exists('BSD_Split_Pay_Stripe_Connect_Woo\bsdwcscsp_fs')) {
                if (\BSD_Split_Pay_Stripe_Connect_Woo\bsdwcscsp_fs()->is__premium_only()) {
                    add_action('plugins_loaded', array($this, 'create_table'));
                }
            } */
        }

        public function bsd_connect_standard_account()
        {

            if (isset($_GET["bsd_action"]) && $_GET["bsd_action"] == "connect_standard_account") {
                global $wpdb;
                $woocommerce_stripe_settings = get_option("woocommerce_stripe_settings");

                $client_id = BSD_SCSP_TEST_CONNECT_ID;

                if (isset($woocommerce_stripe_settings["testmode"]) && $woocommerce_stripe_settings["testmode"] == "yes") {
                    $secret_key = $woocommerce_stripe_settings["test_secret_key"];
                } else {
                    $secret_key = $woocommerce_stripe_settings["secret_key"];
                    $client_id = BSD_SCSP_LIVE_CONNECT_ID;
                }

                if (!empty($woocommerce_stripe_settings) && !empty($secret_key)) {
                    $stripe = new \Stripe\StripeClient(
                        $secret_key
                    );


                    $redirect_uri = site_url("/") . "?bsd_action=get_code";

                    $url = 'https://connect.stripe.com/oauth/authorize?response_type=code';
                    $url = add_query_arg(
                        'client_id',
                        $client_id,
                        $url
                    );
                    $url = add_query_arg('scope', 'read_write', $url);
                    $url = add_query_arg('redirect_uri', urlencode($redirect_uri), $url);

                    wp_redirect($url);
                    exit;
                }
            }
        }

        public function bsd_connect_standard_account_cb()
        {

            if (isset($_GET["bsd_action"]) && $_GET["bsd_action"] == "get_code" && isset($_GET["code"]) && !empty($_GET["code"])) {

                $code = $_GET["code"];

                $woocommerce_stripe_settings = get_option("woocommerce_stripe_settings");

                if (isset($woocommerce_stripe_settings["testmode"]) && $woocommerce_stripe_settings["testmode"] == "yes") {
                    $secret_key = $woocommerce_stripe_settings["test_secret_key"];
                } else {
                    $secret_key = $woocommerce_stripe_settings["secret_key"];
                }
                \Stripe\Stripe::setApiKey($secret_key);

                $stripeResponse = \Stripe\OAuth::token([
                    'grant_type' => 'authorization_code',
                    'code' => $code,
                ]);
                echo "<pre>";
                var_dump($stripeResponse);
                echo "</pre>";
                die;
            }
        }


        public function get_initial_accounts()
        {

            global $wpdb;

            $account_results = $wpdb->get_results("select * from " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . " limit 100", ARRAY_A);

            // $get_all_accounts = get_option("stripe_get_all_accounts", false);
            if (empty($account_results)) {
                $woocommerce_stripe_settings = get_option("woocommerce_stripe_settings");

                if (isset($woocommerce_stripe_settings["testmode"]) && $woocommerce_stripe_settings["testmode"] == "yes") {
                    $secret_key = $woocommerce_stripe_settings["test_secret_key"];
                } else {
                    $secret_key = $woocommerce_stripe_settings["secret_key"];
                }


                if (!empty($woocommerce_stripe_settings) && !empty($secret_key)) {
                    $stripe = new \Stripe\StripeClient(
                        $secret_key
                    );
                    $accounts = $stripe->accounts->all(['limit' => BSD_SCSP_SCA_PER_PAGE]);
                    if ($accounts && is_array($accounts->data)) {
                        $accIndex = 0;
                        foreach ($accounts->data as $acc) {
                            $account_id = $acc->id;
                            $account_name = $acc->business_profile->name;

                            $wpdb->query(
                                $wpdb->prepare(
                                    "insert into " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . " (bsd_account_id, bsd_account_name) values (%s, %s)",
                                    array(
                                        $account_id,
                                        $account_name
                                    )
                                )
                            );

                            $accIndex++;
                        }
                        update_option("last_fetched_account", $account_id);
                    }
                    if (!$accounts->has_more) {
                        update_option("is_all_sca_fetched", true);
                    }


                    // update_option("stripe_get_all_accounts", "1");
                }
            }
            /* $stripe = new \Stripe\StripeClient('sk_test_51HV93LABqnxcBWBVldJgQwR7vBEPEslHjMoWC1uQZebFP77GmcJvtn6au3FTznArM7aDjpt8rBTxUChMzLwRNRBX00fcjRM5Ea');

				$stripe->accounts->update(
					'acct_1Ll5xmPMeveCO27t',
					['tos_acceptance' => ['date' => time(), 'ip' => $_SERVER["REMOTE_ADDR"]]]
				);  */
        }

        public function get_stored_accounts()
        {
            global $wpdb;

            $account_results = $wpdb->get_results("select * from " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . " ", ARRAY_A);
            // $get_all_accounts = get_option("stripe_get_all_accounts", []);
            return $account_results;
        }

        public function fetch_accounts()
        {
            global $wpdb;
            $page = (isset($_POST["page"]) && !empty($_POST["page"])) ? $_POST["page"] : 2;
            $per_page = BSD_SCSP_SCA_PER_PAGE;
            $offset = $per_page * $page;

            $send_ajax_data = array(
                "is_finished" => false,
                "current_page" => $page,
                "offset" => $offset,
                "per_page" => $per_page
            );



            $woocommerce_stripe_settings = get_option("woocommerce_stripe_settings");

            if (isset($woocommerce_stripe_settings["testmode"]) && $woocommerce_stripe_settings["testmode"] == "yes") {
                $secret_key = $woocommerce_stripe_settings["test_secret_key"];
            } else {
                $secret_key = $woocommerce_stripe_settings["secret_key"];
            }


            if (!empty($woocommerce_stripe_settings) && !empty($secret_key)) {
                $stripe = new \Stripe\StripeClient(
                    $secret_key
                );
                $last_fetched_account = get_option("last_fetched_account", false);
                $account_args = [
                    'limit' => $per_page,
                ];
                if ($last_fetched_account) {
                    $account_args['starting_after'] = $last_fetched_account;
                }
                $accounts = $stripe->accounts->all($account_args);

                if ($accounts && is_array($accounts->data)) {
                    $accIndex = 0;
                    $get_all_accounts = array();
                    foreach ($accounts->data as $acc) {
                        $account_id = $acc->id;
                        $account_name = $acc->business_profile->name;
                        $row = $wpdb->get_row(
                            $wpdb->prepare(
                                "select * from " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . "  where bsd_account_id = %s",
                                $account_id
                            ),
                            ARRAY_A
                        );

                        if (empty($row)) {
                            $wpdb->query(
                                $wpdb->prepare(
                                    "insert into " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . " (bsd_account_id, bsd_account_name) values (%s, %s)",
                                    array(
                                        $account_id,
                                        $account_name
                                    )
                                )
                            );

                            $get_all_accounts[$accIndex]["account_id"] = $account_id;
                            $get_all_accounts[$accIndex]["account_name"] = $account_name;
                            $accIndex++;
                        }
                    }
                    update_option("last_fetched_account", $account_id);
                }

                if ($accounts->has_more) {
                    $send_ajax_data = array(
                        "is_finished" => false,
                        "current_page" => $page + 1,
                        "offset" => $page * $per_page,
                        "per_page" => $per_page,
                        "new_account_ids" => $get_all_accounts
                    );
                } else {
                    $send_ajax_data = array(
                        "is_finished" => true,
                    );
                    if (!empty($get_all_accounts)) {
                        $send_ajax_data["new_account_ids"] = $get_all_accounts;
                        update_option("is_all_sca_fetched", true);
                    }
                }
            } else {
                $send_ajax_data = array(
                    "is_finished" => true,
                );
            }

            wp_send_json($send_ajax_data);
            die;
        }

        public function add_custom_account()
        {
            if (isset($_POST["account_id"]) && !empty($_POST["account_id"])) {
                $account_id = $_POST["account_id"];
                global $wpdb;
                $row = $wpdb->get_row(
                    $wpdb->prepare(
                        "select * from " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . "  where bsd_account_id = %s",
                        $account_id
                    ),
                    ARRAY_A
                );

                if (empty($row)) {
                    $wpdb->query(
                        $wpdb->prepare(
                            "insert into " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . " (bsd_account_id) values (%s)",
                            array(
                                $account_id
                            )
                        )
                    );
                }
                wp_send_json(["success" => true]);
                die;
            }
        }
        public function clear_accounts()
        {

            global $wpdb;
            $wpdb->query(
                $wpdb->prepare(
                    "delete from " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . " "
                )
            );

            delete_option("last_fetched_account");
            delete_option("is_all_sca_fetched");


            wp_send_json(["success" => true]);
            die;
        }

        public function create_table()
        {
            global $wpdb, $bsd_stripe_account_tbl_ver;
            $bsd_stripe_account_tbl_installed_ver = get_option("bsd_stripe_account_tbl_ver");
            if ($bsd_stripe_account_tbl_installed_ver != $bsd_stripe_account_tbl_ver) {
                $charset_collate = $wpdb->get_charset_collate();

                $sql = "CREATE TABLE IF NOT EXISTS " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . " (
					bsd_sat_id bigint(20) NOT NULL AUTO_INCREMENT,
					bsd_account_id varchar(55) DEFAULT '' NOT NULL,
					bsd_account_name varchar(55) DEFAULT '' NOT NULL,
					PRIMARY KEY  (bsd_sat_id)
				) $charset_collate;";

                require_once ABSPATH . 'wp-admin/includes/upgrade.php';
                dbDelta($sql);

                add_option('bsd_stripe_account_tbl_ver', $bsd_stripe_account_tbl_ver);

                $bsd_split_pay_stripe_connect_woo_stripe_connected_account = get_option('bsd_split_pay_stripe_connect_woo_stripe_connected_account');


                $wpdb->query(
                    $wpdb->prepare(
                        "insert into " . $wpdb->prefix . BSD_SCSP_STRP_ACCNT_TABLE . " (bsd_account_id) values (%s)",
                        array(
                            $bsd_split_pay_stripe_connect_woo_stripe_connected_account
                        )
                    )
                );
            }
        }
    }
}