<?php

namespace BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin;

if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'BSD_SCSP_WP_List_Table' ) ) {
  include_once 'class-bsd-split-pay-stripe-connect-woo-wp-list-table.php';
}

if ( ! class_exists( 'BSD_SCSP_List_Table_Transfers' ) ) :

class BSD_SCSP_List_Table_Transfers extends BSD_SCSP_WP_List_Table {

  public function __construct() {

      parent::__construct( [
        'singular'  => __( 'Transfer', 'bsd-split-pay-stripe-connect-woo' ),
        'plural'    => __( 'Transfers', 'bsd-split-pay-stripe-connect-woo' ),
        'ajax'      => false
      ]);

      add_action( 'admin_head', array( $this, 'admin_header' ) );
  }

    /**
    *  Associative array of columns
    * @version   1.0.0
    */
    public function get_columns() {
      $columns = array(
        'id'                    => __( 'ID', 'bsd-split-pay-stripe-connect-woo' ),
        'wc_order_id'           => __( 'Order ID', 'bsd-split-pay-stripe-connect-woo' ),
        'charge_date'           => __( 'Charge Date', 'bsd-split-pay-stripe-connect-woo' ),
        'charge_amount'         => __( 'Charge Amount', 'bsd-split-pay-stripe-connect-woo' ),
        'transfer_amount'       => __( 'Transfer Amount', 'bsd-split-pay-stripe-connect-woo' ),
        'transfer_destination'  => __( 'Destination Account', 'bsd-split-pay-stripe-connect-woo' ),
        'charge_id'             => __( 'Stripe Charge ID', 'bsd-split-pay-stripe-connect-woo' ),        
        'transfer_id'           => __( 'Stripe Transfer ID', 'bsd-split-pay-stripe-connect-woo' )
      );

      return $columns;
    }

    /**
     * Style the columns
     * TO DO: Not currently working
     * @version   0.0.1
    */
    function admin_header() {
      $page = ( isset($_GET['page'] ) ) ? sanitize_text_field( $_GET['page'] ) : false;
      //error_log("The page is {$page}.");
      if( 'my_list_test' != $page )
          return;

      echo '<style type="text/css">';
      echo '.wp-list-table .column-id';
      echo '.wp-list-table .column-wc_order_id';
      echo '.wp-list-table .column-charge_date'; 
      echo '.wp-list-table .column-charge_amount';
      echo '.wp-list-table .column-transfer_amount';
      echo '.wp-list-table .column-transfer_destination';
      echo '.wp-list-table .column-charge_id';               
      echo '.wp-list-table .column-transfer_id';
      
      echo '</style>';
    }

    /**
     * Render a column when no column specific method exist.
     * @version   1.0.0
    */
    public function column_default( $item, $column_name ) {             
      switch ( $column_name ) {
        case 'id':
        case 'wc_order_id':
        case 'charge_amount':
        case 'transfer_amount':
        case 'charge_id':
        case 'charge_date':
        case 'transfer_id':
        case 'transfer_destination':
          return $item[ $column_name ];
        default:
          return print_r( $item, true) ;
      }
    }

    /**
     * Columns to make sortable.
     * @version   1.0.0
    */
    public function get_sortable_columns() {
      $sortable_columns = array(
        'id'                    => array( 'id', true ),
        'wc_order_id'           => array( 'wc_order_id', true ),
        'charge_date'           => array( 'charge_date', true ),
        'charge_amount'         => array( 'charge_amount', true ),
        'transfer_amount'       => array( 'transfer_amount', true ),
        'transfer_destination'  => array( 'transfer_destination', true ),
        'charge_id'             => array( 'charge_id', true ),
        'transfer_id'           => array( 'transfer_id', true ),
      );

      return $sortable_columns;
    }

    /**
     * Check if Stripe is in test mode or live mode
     * @version   1.0.0
    */
    public function get_stripe_mode() {
      $stripe_mode = 'live';

      $woo_stripe_settings = get_option( 'woocommerce_stripe_settings' );

      if ( isset( $woo_stripe_settings['testmode'] ) ) {
        $stripe_mode = $woo_stripe_settings['testmode'] == 'yes' ? 'test' : 'live';
      }

      return $stripe_mode;
    }

    /**
     * Get count of items
     * @version   1.0.0
    */
    private function get_total_items( $stripe_mode ) {
      global $wpdb;

      $table_name  = $wpdb->prefix . 'bsd_scsp_transfer_log';
      
      $sql = "SELECT COUNT(id) FROM $table_name WHERE stripe_mode = %s";
      
      $result = $wpdb->get_var($wpdb->prepare($sql, $stripe_mode) );

      return $result;
    } 

    /**
     * Retrieve transfer data from the database
     * @version   1.0.0
    */
    public function get_transfers( $stripe_mode, $per_page, $paged ) {

      global $wpdb;

      $table_name  = $wpdb->prefix . 'bsd_scsp_transfer_log';

      $orderby = ( isset( $_REQUEST['orderby'] ) && in_array( $_REQUEST['orderby'], array_keys( $this->get_sortable_columns() ) ) ) ? sanitize_text_field($_REQUEST['orderby']) : 'wc_order_id';
      $order = ( isset($_REQUEST['order'] ) && in_array( $_REQUEST['order'], array( 'asc', 'desc') ) ) ? sanitize_text_field($_REQUEST['order']) : 'desc';
        
      $sql = "SELECT
                  id
                  , wc_order_id
                  , charge_amount
                  , transfer_amount
                  , charge_id
                  , charge_date
                  , transfer_id
                  , transfer_destination
              FROM $table_name
              WHERE stripe_mode = %s
              ORDER BY " . sanitize_sql_orderby( $orderby . ' ' . $order ) . "
              LIMIT %d OFFSET %d";

      // Query output_type will be an associative array with ARRAY_A.
      $query_results = $wpdb->get_results( $wpdb->prepare( $sql, $stripe_mode, $per_page, $paged ), ARRAY_A  );

      return $query_results;
    } 

    /**
     * Text displayed when no customer data is available
     * @version   1.0.0
    */    
    public function no_items() {
      _e( 'No transfer records available.', 'bsd-split-pay-stripe-connect-woo' );
    }                    

    /**
     * Handles data query and filter, sorting, and pagination.
     * @version   1.0.0
    */
    public function prepare_items() {
      $stripe_mode = $this->get_stripe_mode();

      $per_page = 10;

      $columns = $this->get_columns();
      $hidden = array();
      $sortable = $this->get_sortable_columns();

      $this->_column_headers = array( $columns, $hidden, $sortable );

      $total_items = $this->get_total_items( $stripe_mode );

      $paged = isset( $_REQUEST['paged'] ) ? max( 0, intval( $_REQUEST['paged']) - 1 ) : 0;

      $this->items = $this->get_transfers( $stripe_mode, $per_page, $paged );

      $this->set_pagination_args(array(
        'total_items' => $total_items, 
        'per_page'    => $per_page,
        'total_pages' => ceil( $total_items / $per_page )
      ));
    }
    
    protected function pagination( $which ) {
        if ( empty( $this->_pagination_args ) ) {
            return;
        }
    
        $total_items     = $this->_pagination_args['total_items'];
        $total_pages     = $this->_pagination_args['total_pages'];
        $infinite_scroll = false;
        if ( isset( $this->_pagination_args['infinite_scroll'] ) ) {
            $infinite_scroll = $this->_pagination_args['infinite_scroll'];
        }
    
        if ( 'top' === $which && $total_pages > 1 ) {
            $this->screen->render_screen_reader_content( 'heading_pagination' );
        }
    
        $output = '<span class="displaying-num">' . sprintf(
            /* translators: %s: Number of items. */
            _n( '%s item', '%s items', $total_items ),
            number_format_i18n( $total_items )
        ) . '</span>';
    
        $current              = $this->get_pagenum();
        $removable_query_args = wp_removable_query_args();
    
        $current_url = set_url_scheme( 'http://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] );
    
        $current_url = remove_query_arg( $removable_query_args, $current_url );
    
        $page_links = array();
    
        $total_pages_before = '<span class="paging-input">';
        $total_pages_after  = '</span></span>';
    
        $disable_first = false;
        $disable_last  = false;
        $disable_prev  = false;
        $disable_next  = false;
    
        if ( 1 == $current ) {
            $disable_first = true;
            $disable_prev  = true;
        }
        if ( $total_pages == $current ) {
            $disable_last = true;
            $disable_next = true;
        }
    
        if ( $disable_first ) {
            $page_links[] = '<span class="tablenav-pages-navspan button disabled" aria-hidden="true">&laquo;</span>';
        } else {
            $page_links[] = sprintf(
                "<a class='first-page button' href='%s'><span class='screen-reader-text'>%s</span><span aria-hidden='true'>%s</span></a>",
                esc_url( remove_query_arg( 'paged', $current_url ) ),
                __( 'First page' ),
                '&laquo;'
            );
        }
    
        if ( $disable_prev ) {
            $page_links[] = '<span class="tablenav-pages-navspan button disabled" aria-hidden="true">&lsaquo;</span>';
        } else {
            $page_links[] = sprintf(
                "<a class='prev-page button' href='%s'><span class='screen-reader-text'>%s</span><span aria-hidden='true'>%s</span></a>",
                esc_url( add_query_arg( 'paged', max( 1, $current - 1 ), $current_url ) ),
                __( 'Previous page' ),
                '&lsaquo;'
            );
        }
    
        if ( 'bottom' === $which ) {
            $html_current_page  = $current;
            $total_pages_before = '<span class="screen-reader-text">' . __( 'Current Page' ) . '</span><span id="table-paging" class="paging-input"><span class="tablenav-paging-text">';
        } else {
            $html_current_page = sprintf(
                "%s<input class='current-page' id='current-page-selector' type='text' name='paged' value='%s' size='%d' aria-describedby='table-paging' /><span class='tablenav-paging-text'>",
                '<label for="current-page-selector" class="screen-reader-text">' . __( 'Current Page' ) . '</label>',
                $current,
                strlen( $total_pages )
            );
        }
        $html_total_pages = sprintf( "<span class='total-pages'>%s</span>", number_format_i18n( $total_pages ) );
        $page_links[]     = $total_pages_before . sprintf(
            /* translators: 1: Current page, 2: Total pages. */
            _x( '%1$s of %2$s', 'paging' ),
            $html_current_page,
            $html_total_pages
        ) . $total_pages_after;
    
        if ( $disable_next ) {
            $page_links[] = '<span class="tablenav-pages-navspan button disabled" aria-hidden="true">&rsaquo;</span>';
        } else {
            $page_links[] = sprintf(
                "<a class='next-page button' href='%s'><span class='screen-reader-text'>%s</span><span aria-hidden='true'>%s</span></a>",
                esc_url( add_query_arg( 'paged', min( $total_pages, $current + 1 ), $current_url ) ),
                __( 'Next page' ),
                '&rsaquo;'
            );
        }
    
        if ( $disable_last ) {
            $page_links[] = '<span class="tablenav-pages-navspan button disabled" aria-hidden="true">&raquo;</span>';
        } else {
            $page_links[] = sprintf(
                "<a class='last-page button' href='%s'><span class='screen-reader-text'>%s</span><span aria-hidden='true'>%s</span></a>",
                esc_url( add_query_arg( 'paged', $total_pages, $current_url ) ),
                __( 'Last page' ),
                '&raquo;'
            );
        }
    
        $pagination_links_class = 'pagination-links';
        if ( ! empty( $infinite_scroll ) ) {
            $pagination_links_class .= ' hide-if-js';
        }
        $output .= "\n<span class='$pagination_links_class'>" . implode( "\n", $page_links ) . '</span>';
    
        if ( $total_pages ) {
            $page_class = $total_pages < 2 ? ' one-page' : '';
        } else {
            $page_class = ' no-pages';
        }
        $this->_pagination = "<div class='tablenav-pages{$page_class}'>$output</div>";
    
        echo $this->_pagination;
    }

  public function single_row_columns( $item ) {
    list( $columns, $hidden ) = $this->get_column_info();
    
    foreach ( $columns as $column_name => $column_display_name ) {
      switch ( $column_name ) {
        case 'id':
          ?>
          <td class='bsd-scsp column-id'>
            <?php echo esc_html( $item['id'] ); ?>
          </td>
          <?php
          break;
        case 'wc_order_id':
          ?>
          <td class='bsd-scsp column-wc_order_id '>
            <?php echo esc_html( $item['wc_order_id'] ) ?>
          </td>
          <?php
          break;
        case 'column-charge_date':
          ?>
          <td class='bsd-scsp column-charge_date'>
            <?php echo esc_html( $item['charge_date'] ); ?>
          </td>
          <?php
          break;
        case 'charge_amount':
          ?>
          <td class='bsd-scsp column-charge_amount'>            
            <?php echo wc_price( $item['charge_amount'] ); ?>
          </td>
          <?php
          break;
        case 'transfer_amount':
          ?>
          <td class='bsd-scsp column-transfer_amount'>
            <?php echo wc_price( $item['transfer_amount'] ); ?>
          </td>
          <?php
          break;
        case 'transfer_destination':
          ?>
          <td class='bsd-scsp column-transfer_destination'>
            <input type='text' value='<?php echo esc_attr( $item['transfer_destination'] ); ?>' size='18' readonly />
          </td>
          <?php
          break;
        case 'charge_id':
          ?>
          <td class='bsd-scsp column-charge_id'><?php echo esc_html( $item['charge_id'] ); ?></td>
          <?php
          break;
        case 'transfer_id':
          ?>
          <td class='bsd-scsp column-transfer_id'><?php echo esc_html( $item['transfer_id'] ); ?></td>
          <?php
          break;
        default:
          echo "<td>";
          echo $this->column_default( $item, $column_name );
          echo "</td>";
      }
    }
  }
}

endif; // class_exists check