<?php

namespace BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin;

if (!function_exists('BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin\bsd_scsp_settings_api')) {
	function bsd_scsp_settings_api()
	{
		// BEGIN Replace legacy options - Added in v2.6
		$legacy_bsd_wc_scsp_stripe_connected_account = get_option('bsd_wc_scsp_stripe_connected_account');
		$legacy_bsd_wc_scsp_transfer_percentage = get_option('bsd_wc_scsp_transfer_percentage');
		$legacy_bsd_wc_scsp_exclude_shipping = get_option('bsd_wc_scsp_exclude_shipping');
		$legacy_bsd_wc_scsp_exclude_tax = get_option('bsd_wc_scsp_exclude_tax');
        
		if ($legacy_bsd_wc_scsp_stripe_connected_account) {
			update_option('bsd_split_pay_stripe_connect_woo_stripe_connected_account', $legacy_bsd_wc_scsp_stripe_connected_account);
			delete_option('bsd_wc_scsp_stripe_connected_account');
		}

		if ($legacy_bsd_wc_scsp_transfer_percentage) {
			update_option('bsd_split_pay_stripe_connect_woo_transfer_percentage', $legacy_bsd_wc_scsp_transfer_percentage);
			delete_option('bsd_wc_scsp_transfer_percentage');
		}

		if ($legacy_bsd_wc_scsp_exclude_shipping) {
			$value = $legacy_bsd_wc_scsp_exclude_shipping == 'yes' ? true : false;
			update_option('bsd_split_pay_stripe_connect_woo_exclude_shipping', $value);
			delete_option('bsd_wc_scsp_exclude_shipping');
		}

		if ($legacy_bsd_wc_scsp_exclude_tax) {
			$value = $legacy_bsd_wc_scsp_exclude_tax == 'yes' ? true : false;
			update_option('bsd_split_pay_stripe_connect_woo_exclude_tax', $value);
			delete_option('bsd_wc_scsp_exclude_tax');
		}
		// END Replace legacy options

		// BEGIN Delete legacy Exclude Shipping and Exclude Tax settings - Added in 3.2
		delete_option('bsd_split_pay_stripe_connect_woo_exclude_shipping');
		delete_option('bsd_split_pay_stripe_connect_woo_exclude_tax');

		register_setting(
			'bsd_scsp_options_main',
			'bsd_split_pay_stripe_connect_woo_stripe_connected_account',
			array(
				'type'              => 'string',
				'show_in_rest'      => true,
				'sanitize_callback' => 'sanitize_text_field'
			)
		);

        register_setting(
			'bsd_scsp_options_main',
			'bsd_spscwt_type',
			array(
				'type'              => 'string',
				'show_in_rest'      => true,
				'sanitize_callback' => 'sanitize_text_field'
			)
		);

		register_setting(
			'bsd_scsp_options_main',
			'bsd_split_pay_stripe_connect_woo_transfer_percentage',
			array(
				'type'              => 'number',
				'show_in_rest'      => true,
				'sanitize_callback' => __NAMESPACE__ . '\\bsd_scsp_settings_int_sanitize'
			)
		);

        register_setting(
			'bsd_scsp_options_main',
			'bsd_spscwt_amount',
			array(
				'type'              => 'number',
				'show_in_rest'      => true,
				'sanitize_callback' => __NAMESPACE__ . '\\bsd_scsp_settings_int_sanitize'
			)
		);

        register_setting(
			'bsd_scsp_options_main',
			'bsd_trnsfr_shpng_fees',
			array(
				'type'              => 'boolean',
				'show_in_rest'      => true,
			)
		);

		

		add_settings_section(
			'bsd_scsp_options_main',
			'Split Pay Plugin Settings',
			__NAMESPACE__ . '\\bsd_scsp_settings_section',
			'bsd-split-pay-stripe-connect-woo'
		);
        
        add_settings_field(
            'bsd_scsp_sync_account_btn',
            '',
            __NAMESPACE__ . '\\bsd_sync_stripe_accounts_btn',
            'bsd-split-pay-stripe-connect-woo',
            'bsd_scsp_options_main'
        );
		

		add_settings_field(
			'bsd_split_pay_stripe_connect_woo_stripe_connected_account',
			'Connected Stripe Account ID',
			__NAMESPACE__ . '\\bsd_split_pay_stripe_connect_woo_stripe_connected_account_input_cb',
			'bsd-split-pay-stripe-connect-woo',
			'bsd_scsp_options_main'
		);

        add_settings_field(
			'bsd_spscwt_type',
			'Default Global Transfer',
			__NAMESPACE__ . '\\bsd_spscwt_type_cb',
			'bsd-split-pay-stripe-connect-woo',
			'bsd_scsp_options_main',
            array( 'class' => 'bsd_spscwt_type_row' )
		);

		add_settings_field(
			'bsd_split_pay_stripe_connect_woo_transfer_percentage',
			'',
			__NAMESPACE__ . '\\bsd_split_pay_stripe_connect_woo_transfer_percentage_input_cb',
			'bsd-split-pay-stripe-connect-woo',
			'bsd_scsp_options_main',
            array( 'class' => 'bsd_hidden' )
		);

        add_settings_field(
			'bsd_spscwt_amount',
			'',
			__NAMESPACE__ . '\\bsd_spscwt_amount_cb',
			'bsd-split-pay-stripe-connect-woo',
			'bsd_scsp_options_main',
            array( 'class' => 'bsd_hidden' )
		);
        add_settings_field(
			'bsd_trnsfr_shpng_fees',
			'Transfer shipping fees to connected accounts',
			__NAMESPACE__ . '\\bsd_trnsfr_shpng_fees_cb',
			'bsd-split-pay-stripe-connect-woo',
			'bsd_scsp_options_main'
		);

		
	}
}

if (!function_exists('BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin\bsd_scsp_settings_section')) {
	function bsd_scsp_settings_section()
	{
        
            $upgrade_url = '?billing_cycle=annual&page=bsd-split-pay-stripe-connect-woo-pricing';

            if (function_exists('bsdwcscsp_fs')) {
                $upgrade_url = bsdwcscsp_fs()->get_upgrade_url();
            }

            $text = 'The Connected Stripe Account ID should be the Account ID for one of your connected accounts. You can easily onboard connected accounts in the Stripe Dashboard.';
            $text .= ' In the future, we plan to have a simple mechanism for onboarding vendors through the WordPress Dashboard.';
            $text .= ' For questions about how to configure the settings below, please refer to our';
            $text .= ' <a href="https://docs.splitpayplugin.com/" target="_blank">Documentation</a>.';
            if (!(\BSD_Split_Pay_Stripe_Connect_Woo\bsdwcscsp_fs()->can_use_premium_code())) {
                $text .= ' <a href="' . esc_url($upgrade_url) . '" target="_blank">' . esc_html(__('Upgrade Now >', 'bsd-split-pay-stripe-connect-woo')) . '</a>';
            }

            echo '<p>' . wp_kses_post($text) . ' </p>';
        
	}
}

if (!function_exists('BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin\bsd_scsp_settings_int_sanitize')) {
	function bsd_scsp_settings_int_sanitize($input)
	{
		if (is_array($input)) {
			$input['quantity'] = absint($input['quantity']);

			if ($input['quantity'] > 100)
				$input['quantity'] = 100;
		} else {
			$input = absint($input);

			if ($input > 100)
				$input = 100;
		}

		return $input;
	}
}

if (!function_exists('BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin\bsd_sync_stripe_accounts_btn')) {
	function bsd_sync_stripe_accounts_btn()
	{

        $woocommerce_stripe_settings = get_option("woocommerce_stripe_settings");
        if(empty($woocommerce_stripe_settings)){
            echo esc_html("Please add strip details.", 'bsd-split-pay-stripe-connect-woo');
            return "";
        }
		$is_all_sca_fetched = get_option('is_all_sca_fetched', false);

?>
		<a href="javascript:;" id="sync_accounts_btn" class="button button-secondary bsd-spscws-btns" style="display: none;">

			<span id="sync_btn_text">
				<?php esc_html_e("Synchronize Stripe Accounts"); ?>
			</span>
			<img src="<?php echo BSD_SCSP_PLUGIN_URI; ?>assets/loader.gif" alt="loader" class="bsd_loader" />
		</a>

		<?php
		if ($is_all_sca_fetched) {
		?>
			<a href="javascript:;" id="csync_accounts_btn" class="button button-secondary bsd-spscws-btns" style="display: none;">

				<span id="csync_btn_text">
					<?php esc_html_e("Clear Synced Stripe Data"); ?>
				</span>
				<img src="<?php echo BSD_SCSP_PLUGIN_URI; ?>assets/loader.gif" alt="loader" class="bsd_loader" />
			</a>
			<style>
				.bsd-spscws-btns {
					margin-bottom: 10px !important;
				}
			</style>
		<?php
		}
		?>


		<p class="bsd-scsp-helper-text"><?php echo __("Syncing allows you to search Connected Stripe accounts by Account Name or ID.") ?></p>



	<?php
	}
}

if (!function_exists('BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin\bsd_split_pay_stripe_connect_woo_stripe_connected_account_input_cb')) {
	function bsd_split_pay_stripe_connect_woo_stripe_connected_account_input_cb()
	{
		global $bsd_sca;
		$bsd_split_pay_stripe_connect_woo_stripe_connected_account = get_option('bsd_split_pay_stripe_connect_woo_stripe_connected_account');
		$get_accounts = $bsd_sca->get_stored_accounts();
       

	?>
		<div class="bsd_stripe_select_wrapper">
            <select name="bsd_split_pay_stripe_connect_woo_stripe_connected_account" id="sspscwsca_select" class="sspscwsca_select">
                <?php
                if (!empty($get_accounts)) {
                    ?>
                        <option value=""><?php esc_html_e("Select", 'bsd-split-pay-stripe-connect-woo') ?></option>
                    <?php
                    foreach ($get_accounts as $gak) {
                ?>
                        <option value="<?php echo $gak["bsd_account_id"]; ?>" <?php echo ($bsd_split_pay_stripe_connect_woo_stripe_connected_account == $gak["bsd_account_id"]) ? "selected='selected'" : ""; ?>><?php echo empty($gak["bsd_account_name"]) ? $gak["bsd_account_id"] : $gak["bsd_account_name"]; ?></option>
                <?php
                    }
                }
                ?>

            </select>
            <?php 
                ?>
                    <button id="copy_account_id" type="button"><?php esc_html_e("Copy Account ID"); ?></button>
        </div>
            <?php
		?>
		
		
	<?php
	}
}

if (!function_exists('BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin\bsd_spscwt_type_cb')) {
	function bsd_spscwt_type_cb()
	{
        $bsd_spscwt_type = get_option('bsd_spscwt_type');
        // echo esc_attr($bsd_spscwt_type ?? "");

        $bsd_split_pay_stripe_connect_woo_transfer_percentage = get_option('bsd_split_pay_stripe_connect_woo_transfer_percentage');
        $bsd_spscwt_amount = get_option('bsd_spscwt_amount');
	?>
        <select name="bsd_spscwt_type" id="bsd_spscwt_type">
            <option value="percentage" <?php echo ($bsd_spscwt_type == "percentage")? "selected='selected'":""; ?>><?php echo __("Percentage") ?></option>
            <?php 
            
                if (\BSD_Split_Pay_Stripe_Connect_Woo\bsdwcscsp_fs()->can_use_premium_code()) {
                    ?>
                        <option value="amount" <?php echo ($bsd_spscwt_type == "amount")? "selected='selected'":""; ?>><?php echo __("Fixed Amount") ?></option>
                    <?php
                }else{
                    ?>
                        <option value="amount" <?php echo ($bsd_spscwt_type == "amount")? "selected='selected'":""; ?> disabled="true"><?php echo __("Fixed Amount") ?></option>
                    <?php
                }
            ?>
        </select>
        
        <input type='number' min='0' step='1' id='bsd_split_pay_stripe_connect_woo_transfer_percentage' name='bsd_split_pay_stripe_connect_woo_transfer_percentage' value="<?php echo esc_attr($bsd_split_pay_stripe_connect_woo_transfer_percentage ?? ""); ?>" class="bsd_spscwtp_input <?php echo (empty($bsd_spscwt_type) || $bsd_spscwt_type == "percentage")? "":"bsd_hidden"; ?>"  />

        <input type='number' min='0' step='1' id='bsd_spscwt_amount' name='bsd_spscwt_amount' value="<?php echo esc_attr($bsd_spscwt_amount ?? ""); ?>" class="bsd_spscwt_amount <?php echo ($bsd_spscwt_type == "amount")? "":"bsd_hidden"; ?>"  />
        <?php  
        $upgrade_url = BSD_SCSP_PLUGIN_UPGRADE_URL;

		if (function_exists('bsdwcscsp_fs')) {
			$upgrade_url = bsdwcscsp_fs()->get_upgrade_url();
		}
        ?>
            <p class="bsd-scsp-helper-text"><?php echo __("Used if a product-level transfer value is not set."); ?></p>
        <?php
        if (!(\BSD_Split_Pay_Stripe_Connect_Woo\bsdwcscsp_fs()->can_use_premium_code())) { ?>
            <p class="bsd-scsp-helper-text"><?php esc_html_e("For Fixed amount transfers, please" , 'bsd-split-pay-stripe-connect-woo'); ?> <a href="<?php echo esc_url($upgrade_url); ?>"><?php esc_html_e("Upgrade >" , 'bsd-split-pay-stripe-connect-woo'); ?></a>.</p>
		<?php } ?>
<?php
	}
}

if (!function_exists('BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin\bsd_split_pay_stripe_connect_woo_transfer_percentage_input_cb')) {
	function bsd_split_pay_stripe_connect_woo_transfer_percentage_input_cb()
	{}
}

if (!function_exists('BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin\bsd_spscwt_amount_cb')) {
	function bsd_spscwt_amount_cb()
	{}
}
if (!function_exists('BSD_Split_Pay_Stripe_Connect_Woo\Inc\Admin\bsd_trnsfr_shpng_fees_cb')) {
	function bsd_trnsfr_shpng_fees_cb()
	{
        $bsd_trnsfr_shpng_fees = get_option('bsd_trnsfr_shpng_fees');

        $upgrade_url = BSD_SCSP_PLUGIN_UPGRADE_URL;

		if (function_exists('bsdwcscsp_fs')) {
			$upgrade_url = bsdwcscsp_fs()->get_upgrade_url();
		}

        ?>

        <?php
        if (\BSD_Split_Pay_Stripe_Connect_Woo\bsdwcscsp_fs()->can_use_premium_code()) { ?>
            <input type='checkbox' id='bsd_trnsfr_shpng_fees' name='bsd_trnsfr_shpng_fees' value="1" class="bsd_trnsfr_shpng_fees" <?php echo ($bsd_trnsfr_shpng_fees == "1")? "checked='true'":""; ?>  />
            
		<?php }else{
            ?>
                <input type='checkbox'  disabled  />
                <p class="bsd-scsp-helper-text"><?php esc_html_e("To transfer shipping fees to connected accounts, please" , 'bsd-split-pay-stripe-connect-woo'); ?> <a href="<?php echo esc_url($upgrade_url); ?>"><?php esc_html_e("Upgrade >" , 'bsd-split-pay-stripe-connect-woo'); ?></a>.</p>
            <?php
        } ?>


            
        <?php
    }
}